From: bugzilla-daemon@freedesktop.org
To: dri-devel@lists.freedesktop.org
Subject: [Bug 60879] [radeonsi] X11 can't start with acceleration enabled
Date: Tue, 04 Jun 2013 20:33:16 +0000 [thread overview]
Message-ID: <bug-60879-502-Q5IyY9UMte@http.bugs.freedesktop.org/> (raw)
In-Reply-To: <bug-60879-502@http.bugs.freedesktop.org/>
[-- Attachment #1.1: Type: text/plain, Size: 3043 bytes --]
https://bugs.freedesktop.org/show_bug.cgi?id=60879
--- Comment #37 from Hristo Venev <mustrumr97@gmail.com> ---
I updated llvm, clang and mesa. Division and modulo still don't work. Another
thing I noticed is that ifs which depend on memory loads cause llvm crash:
__kernel void add(__global const uint *a, __global const uint *b, __global
uint *c){
ulong id=get_global_id(0); // OK
if(id>10) return; // OK
if(b[id]==0) return; // crash
c[id]=a[id]/b[id]; // GPU hang
}
a[id] is id+1
b[id] is 2*id+2
Stack dump:
0. Running pass 'Function Pass Manager' on module 'radeon'.
1. Running pass 'AMDGPU DAG->DAG Pattern Instruction Selection' on function
'@add'
Segmentation fault
#0 0x00007ffff461c8a7 in ?? () from /usr/lib64/llvm/libLLVM-3.4svn.so
#1 0x00007ffff3e36208 in llvm::SelectionDAGISel::DoInstructionSelection() ()
from /usr/lib64/llvm/libLLVM-3.4svn.so
#2 0x00007ffff3e3c620 in llvm::SelectionDAGISel::CodeGenAndEmitDAG() () from
/usr/lib64/llvm/libLLVM-3.4svn.so
#3 0x00007ffff3e3e0f2 in
llvm::SelectionDAGISel::SelectAllBasicBlocks(llvm::Function const&) () from
/usr/lib64/llvm/libLLVM-3.4svn.so
#4 0x00007ffff3e3f421 in
llvm::SelectionDAGISel::runOnMachineFunction(llvm::MachineFunction&) () from
/usr/lib64/llvm/libLLVM-3.4svn.so
#5 0x00007ffff3acaeb2 in llvm::FPPassManager::runOnFunction(llvm::Function&)
() from /usr/lib64/llvm/libLLVM-3.4svn.so
#6 0x00007ffff3acaf4b in llvm::FPPassManager::runOnModule(llvm::Module&) ()
from /usr/lib64/llvm/libLLVM-3.4svn.so
#7 0x00007ffff3acb195 in llvm::MPPassManager::runOnModule(llvm::Module&) ()
from /usr/lib64/llvm/libLLVM-3.4svn.so
#8 0x00007ffff3acd1dc in llvm::PassManagerImpl::run(llvm::Module&) () from
/usr/lib64/llvm/libLLVM-3.4svn.so
#9 0x00007ffff417c009 in ?? () from /usr/lib64/llvm/libLLVM-3.4svn.so
#10 0x00007ffff417c382 in LLVMTargetMachineEmitToMemoryBuffer () from
/usr/lib64/llvm/libLLVM-3.4svn.so
#11 0x00007ffff2ae6ab1 in radeon_llvm_compile () from
/usr/lib64/gallium-pipe/pipe_radeonsi.so
#12 0x00007ffff2adc65d in si_compile_llvm () from
/usr/lib64/gallium-pipe/pipe_radeonsi.so
#13 0x00007ffff2adef79 in ?? () from /usr/lib64/gallium-pipe/pipe_radeonsi.so
#14 0x00007ffff6d882a7 in _cl_kernel::exec_context::bind(_cl_command_queue*) ()
from /usr/lib64/libOpenCL.so.1
#15 0x00007ffff6d88e46 in _cl_kernel::launch(_cl_command_queue&,
std::vector<unsigned long, std::allocator<unsigned long> > const&,
std::vector<unsigned long, std::allocator<unsigned long> > const&,
std::vector<unsigned long, std::allocator<unsigned long> > const&) () from
/usr/lib64/libOpenCL.so.1
#16 0x00007ffff6d847dc in _cl_event::trigger() () from
/usr/lib64/libOpenCL.so.1
#17 0x00007ffff6d84e54 in clover::hard_event::hard_event(_cl_command_queue&,
unsigned int, std::vector<_cl_event*, std::allocator<_cl_event*> >,
std::function<void (_cl_event&)>) ()
from /usr/lib64/libOpenCL.so.1
#18 0x00007ffff6d9fad5 in clEnqueueNDRangeKernel () from
/usr/lib64/libOpenCL.so.1
--
You are receiving this mail because:
You are the assignee for the bug.
[-- Attachment #1.2: Type: text/html, Size: 3936 bytes --]
[-- Attachment #2: Type: text/plain, Size: 159 bytes --]
_______________________________________________
dri-devel mailing list
dri-devel@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/dri-devel
next prev parent reply other threads:[~2013-06-04 20:33 UTC|newest]
Thread overview: 183+ messages / expand[flat|nested] mbox.gz Atom feed top
2013-02-15 8:51 [Bug 60879] New: X11 can't start with acceleration enabled bugzilla-daemon
2013-02-15 8:52 ` [Bug 60879] " bugzilla-daemon
2013-02-15 8:53 ` bugzilla-daemon
2013-02-15 9:12 ` bugzilla-daemon
2013-02-21 19:08 ` bugzilla-daemon
2013-02-22 10:40 ` bugzilla-daemon
2013-02-22 18:22 ` bugzilla-daemon
2013-02-22 19:30 ` bugzilla-daemon
2013-02-23 14:36 ` bugzilla-daemon
2013-03-06 11:17 ` bugzilla-daemon
2013-03-08 16:27 ` bugzilla-daemon
2013-03-08 17:01 ` bugzilla-daemon
2013-03-13 15:20 ` bugzilla-daemon
2013-03-13 20:57 ` bugzilla-daemon
2013-03-22 21:06 ` bugzilla-daemon
2013-03-22 21:16 ` bugzilla-daemon
2013-03-22 21:56 ` bugzilla-daemon
2013-03-23 12:11 ` bugzilla-daemon
2013-03-25 14:39 ` bugzilla-daemon
2013-03-25 14:44 ` bugzilla-daemon
2013-03-25 18:43 ` bugzilla-daemon
2013-03-29 13:23 ` bugzilla-daemon
2013-03-29 14:27 ` bugzilla-daemon
2013-04-20 19:37 ` bugzilla-daemon
2013-04-20 22:33 ` bugzilla-daemon
2013-04-21 8:54 ` bugzilla-daemon
2013-04-21 13:30 ` bugzilla-daemon
2013-04-22 17:03 ` bugzilla-daemon
2013-04-24 19:07 ` [Bug 60879] [radeonsi] " bugzilla-daemon
2013-04-30 11:59 ` bugzilla-daemon
2013-05-12 19:17 ` bugzilla-daemon
2013-05-12 23:01 ` bugzilla-daemon
2013-05-18 19:31 ` bugzilla-daemon
2013-05-18 23:18 ` bugzilla-daemon
2013-05-19 10:54 ` bugzilla-daemon
2013-06-04 7:50 ` bugzilla-daemon
2013-06-04 17:12 ` bugzilla-daemon
2013-06-04 20:33 ` bugzilla-daemon [this message]
2013-06-04 21:49 ` bugzilla-daemon
2013-07-24 9:19 ` bugzilla-daemon
2013-09-16 13:54 ` bugzilla-daemon
2013-10-21 6:21 ` bugzilla-daemon
2013-10-21 15:49 ` bugzilla-daemon
2013-10-21 23:28 ` bugzilla-daemon
2013-10-22 6:08 ` bugzilla-daemon
2013-10-22 14:22 ` bugzilla-daemon
2013-10-22 14:22 ` bugzilla-daemon
2013-10-22 17:36 ` bugzilla-daemon
2013-10-22 17:52 ` bugzilla-daemon
2013-10-22 18:18 ` bugzilla-daemon
2013-10-23 8:13 ` bugzilla-daemon
2013-12-03 19:51 ` bugzilla-daemon
2014-01-08 19:39 ` bugzilla-daemon
2014-01-13 17:10 ` bugzilla-daemon
2014-01-14 8:39 ` bugzilla-daemon
2014-01-22 20:30 ` bugzilla-daemon
2014-01-25 14:06 ` bugzilla-daemon
2014-01-28 20:15 ` bugzilla-daemon
2014-01-29 7:55 ` bugzilla-daemon
2014-01-30 2:31 ` bugzilla-daemon
2014-01-30 22:22 ` bugzilla-daemon
2014-02-05 15:14 ` bugzilla-daemon
2014-02-05 22:32 ` bugzilla-daemon
2014-02-06 7:35 ` bugzilla-daemon
2014-02-06 19:37 ` bugzilla-daemon
2014-02-19 3:35 ` bugzilla-daemon
2014-02-26 18:28 ` bugzilla-daemon
2014-03-03 19:55 ` bugzilla-daemon
2014-03-14 11:58 ` bugzilla-daemon
2014-04-02 10:12 ` bugzilla-daemon
2014-04-06 10:45 ` bugzilla-daemon
2014-04-09 15:13 ` bugzilla-daemon
2014-04-11 10:27 ` bugzilla-daemon
2014-04-30 14:24 ` bugzilla-daemon
2014-04-30 18:02 ` bugzilla-daemon
2014-04-30 18:04 ` bugzilla-daemon
2014-04-30 19:30 ` bugzilla-daemon
2014-05-02 0:30 ` bugzilla-daemon
2014-05-02 3:25 ` bugzilla-daemon
2014-05-02 11:40 ` bugzilla-daemon
2014-05-03 12:01 ` bugzilla-daemon
2014-05-03 13:02 ` bugzilla-daemon
2014-05-26 7:55 ` bugzilla-daemon
2014-08-07 14:35 ` bugzilla-daemon
2014-08-11 16:01 ` bugzilla-daemon
2014-08-11 16:06 ` bugzilla-daemon
2014-08-15 10:34 ` bugzilla-daemon
2014-09-09 20:10 ` bugzilla-daemon
2014-09-09 21:02 ` bugzilla-daemon
2014-09-10 2:30 ` bugzilla-daemon
2014-09-11 1:19 ` bugzilla-daemon
2014-09-11 8:49 ` bugzilla-daemon
2014-09-19 1:21 ` bugzilla-daemon
2014-09-19 20:43 ` bugzilla-daemon
2014-09-19 20:44 ` bugzilla-daemon
2014-09-19 20:46 ` bugzilla-daemon
2014-09-19 21:40 ` bugzilla-daemon
2014-09-19 22:33 ` bugzilla-daemon
2014-09-22 7:06 ` bugzilla-daemon
2014-09-22 13:30 ` bugzilla-daemon
2014-09-22 13:33 ` bugzilla-daemon
2014-09-22 15:51 ` bugzilla-daemon
2014-09-22 15:59 ` bugzilla-daemon
2014-09-24 2:23 ` bugzilla-daemon
2014-10-04 13:35 ` bugzilla-daemon
2014-10-04 13:37 ` bugzilla-daemon
2014-10-04 13:42 ` bugzilla-daemon
2014-10-25 18:38 ` bugzilla-daemon
2014-10-25 18:39 ` bugzilla-daemon
2014-10-27 7:46 ` bugzilla-daemon
2014-12-05 18:57 ` bugzilla-daemon
2014-12-09 16:36 ` bugzilla-daemon
2014-12-09 16:45 ` bugzilla-daemon
2014-12-09 16:54 ` bugzilla-daemon
2015-11-20 0:50 ` bugzilla-daemon
2015-11-20 0:51 ` bugzilla-daemon
2015-11-20 0:51 ` bugzilla-daemon
2015-11-20 1:13 ` bugzilla-daemon
2015-11-20 1:14 ` bugzilla-daemon
2015-11-20 14:55 ` bugzilla-daemon
2015-11-21 12:08 ` bugzilla-daemon
2015-11-21 13:29 ` bugzilla-daemon
2015-11-22 0:44 ` bugzilla-daemon
2015-11-22 0:44 ` bugzilla-daemon
2015-11-22 0:45 ` bugzilla-daemon
2015-11-22 1:06 ` bugzilla-daemon
2016-02-07 0:42 ` bugzilla-daemon
2016-02-09 20:50 ` bugzilla-daemon
2016-02-09 20:50 ` bugzilla-daemon
2016-02-16 19:01 ` bugzilla-daemon
2016-02-16 19:16 ` bugzilla-daemon
2016-02-16 20:41 ` bugzilla-daemon
2016-02-17 0:54 ` bugzilla-daemon
2016-02-27 21:18 ` bugzilla-daemon
2016-03-08 22:44 ` bugzilla-daemon
2016-03-09 16:35 ` bugzilla-daemon
2016-03-10 4:53 ` bugzilla-daemon
2016-03-10 8:31 ` bugzilla-daemon
2016-03-10 10:01 ` bugzilla-daemon
2016-03-10 10:41 ` bugzilla-daemon
2016-03-10 10:41 ` bugzilla-daemon
2016-03-10 21:26 ` bugzilla-daemon
2016-03-10 22:29 ` bugzilla-daemon
2016-03-11 14:04 ` bugzilla-daemon
2016-03-11 21:38 ` bugzilla-daemon
2016-03-11 21:59 ` bugzilla-daemon
2016-03-11 22:07 ` bugzilla-daemon
2016-03-11 22:24 ` bugzilla-daemon
2016-03-11 23:21 ` bugzilla-daemon
2016-03-11 23:43 ` [Bug 60879] [radeonsi] Tahiti LE: GFX block is not functional, CP is okay bugzilla-daemon
2016-04-28 19:00 ` bugzilla-daemon
2016-06-05 2:11 ` bugzilla-daemon
2016-06-05 2:23 ` bugzilla-daemon
2016-10-09 10:09 ` bugzilla-daemon
2016-10-09 14:17 ` bugzilla-daemon
2016-10-09 14:35 ` bugzilla-daemon
2016-10-09 17:26 ` bugzilla-daemon
2016-10-09 17:54 ` bugzilla-daemon
2016-10-11 20:30 ` bugzilla-daemon
2016-10-12 3:11 ` bugzilla-daemon
2016-10-15 10:57 ` bugzilla-daemon
2016-11-25 7:19 ` bugzilla-daemon
2016-12-03 10:56 ` bugzilla-daemon
2016-12-11 9:17 ` bugzilla-daemon
2016-12-13 18:27 ` bugzilla-daemon
2017-03-22 16:05 ` bugzilla-daemon
2017-08-03 21:06 ` bugzilla-daemon
2017-08-03 21:10 ` bugzilla-daemon
2017-08-03 21:11 ` bugzilla-daemon
2017-08-03 21:14 ` bugzilla-daemon
2017-09-20 19:47 ` bugzilla-daemon
2017-09-30 14:58 ` bugzilla-daemon
2017-11-04 20:45 ` bugzilla-daemon
2017-11-04 21:14 ` bugzilla-daemon
2018-03-20 22:30 ` bugzilla-daemon
2019-02-01 7:49 ` bugzilla-daemon
2019-02-03 10:01 ` bugzilla-daemon
2019-02-03 10:01 ` bugzilla-daemon
2019-02-03 10:02 ` bugzilla-daemon
2019-02-03 10:03 ` bugzilla-daemon
2019-07-20 0:48 ` bugzilla-daemon
2019-09-20 13:37 ` bugzilla-daemon
2019-09-25 17:50 ` bugzilla-daemon
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=bug-60879-502-Q5IyY9UMte@http.bugs.freedesktop.org/ \
--to=bugzilla-daemon@freedesktop.org \
--cc=dri-devel@lists.freedesktop.org \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox